---
description: 'Learn about resources supported by Databricks Asset Bundles and how to configure them.'
last_update:
  date: 2025-02-14
---

<!-- DO NOT EDIT. This file is autogenerated with https://github.com/databricks/cli -->

# :re[DABS] resources

:re[DABS] allows you to specify information about the :re[Databricks] resources used by the bundle in the `resources` mapping in the bundle configuration. See [resources mapping](/dev-tools/bundles/settings.md#resources) and [resources key reference](/dev-tools/bundles/reference.md#resources).

This article outlines supported resource types for bundles and provides details and an example for each supported type. For additional examples, see [\_](/dev-tools/bundles/resource-examples.md).

:::tip

To generate YAML for any existing resource, use the `databricks bundle generate` command. See [\_](/dev-tools/cli/bundle-commands.md#generate).

:::

## <a id="resource-types"></a>Supported resources

The following table lists supported resource types for bundles. Some resources can be created by defining them in a bundle and deploying the bundle, and some resources only support referencing an existing resource to include in the bundle.

Resources are defined using the corresponding [Databricks REST API](https://docs.databricks.com/api/workspace/introduction) object’s create operation request payload, where the object’s supported fields, expressed as YAML, are the resource’s supported properties. Links to documentation for each resource’s corresponding payloads are listed in the table.

:::tip

The `databricks bundle validate` command returns warnings if unknown resource properties are found in bundle configuration files.

:::

::::aws-azure

:::list-table

- - Resource
  - Create support
  - Corresponding REST API object
- - [app](#apps)
  - ✓
  - [App object](https://docs.databricks.com/api/workspace/apps/create)
- - [cluster](#clusters)
  - ✓
  - [Cluster object](https://docs.databricks.com/api/workspace/clusters/create)
- - [dashboard](#dashboards)
  -
  - [Dashboard object](https://docs.databricks.com/api/workspace/lakeview/create)
- - [experiment](#experiments)
  - ✓
  - [Experiment object](https://docs.databricks.com/api/workspace/experiments/createexperiment)
- - [job](#job)
  - ✓
  - [Job object](https://docs.databricks.com/api/workspace/jobs/create)
- - [model (legacy)](#models)
  - ✓
  - [Model (legacy) object](https://docs.databricks.com/api/workspace/modelregistry/createmodel)
- - [model_serving_endpoint](#model_serving_endpoints)
  - ✓
  - [Model serving endpoint object](https://docs.databricks.com/api/workspace/servingendpoints/create)
- - [pipeline](#pipeline)
  - ✓
  - [Pipeline object](https://docs.databricks.com/api/workspace/pipelines/create)
- - [quality_monitor](#quality_monitors)
  - ✓
  - [Quality monitor object](https://docs.databricks.com/api/workspace/qualitymonitors/create)
- - [registered_model](#registered_models) (:re[UC])
  - ✓
  - [Registered model object](https://docs.databricks.com/api/workspace/registeredmodels/create)
- - [schema](#schemas) (:re[UC])
  - ✓
  - [Schema object](https://docs.databricks.com/api/workspace/schemas/create)
- - [volume](#volumes) (:re[UC])
  - ✓
  - [Volume object](https://docs.databricks.com/api/workspace/volumes/create)

:::

::::

::::gcp

:::list-table

- - Resource
  - Create support
  - Corresponding REST API object
- - [cluster](#clusters)
  - ✓
  - [Cluster object](https://docs.databricks.com/api/workspace/clusters/create)
- - [dashboard](#dashboards)
  -
  - [Dashboard object](https://docs.databricks.com/api/workspace/lakeview/create)
- - [experiment](#experiments)
  - ✓
  - [Experiment object](https://docs.databricks.com/api/workspace/experiments/createexperiment)
- - [job](#jobs)
  - ✓
  - [Job object](https://docs.databricks.com/api/workspace/jobs/create)
- - [model (legacy)](#models)
  - ✓
  - [Model (legacy) object](https://docs.databricks.com/api/workspace/modelregistry/createmodel)
- - [model_serving_endpoint](#model_serving_endpoints)
  - ✓
  - [Model serving endpoint object](https://docs.databricks.com/api/workspace/servingendpoints/create)
- - [pipeline](#pipelines)
  - ✓
  - [Pipeline object]](https://docs.databricks.com/api/workspace/pipelines/create)
- - [quality_monitor](#quality_monitors)
  - ✓
  - [Quality monitor object](https://docs.databricks.com/api/workspace/qualitymonitors/create)
- - [registered_model](#registered_models) (:re[UC])
  - ✓
  - [Registered model object](https://docs.databricks.com/api/workspace/registeredmodels/create)
- - [schema](#schemas) (:re[UC])
  - ✓
  - [Schema object](https://docs.databricks.com/api/workspace/schemas/create)
- - [volume](#volumes) (:re[UC])
  - ✓
  - [Volume object](https://docs.databricks.com/api/workspace/volumes/create)

:::

::::
